#####################################################################################################
#####################################################################################################
### RANDOMIZATION
#####################################################################################################
# wd <- "C:/Users/RV Bangarang/" # Samsung
wd <-  "/Users/eric.keen/"  # Mac
#wd <- "D:/" # Samsung II
#####################################################################################################
#####################################################################################################
setwd(paste(wd,"Dropbox/Bangarang Docs/Humpback-shifts/randomization",sep=""))
source("effortcorrect.R")
source("julian.R") ## Load Julian Pooling funct
#####################################################################################################
#####################################################################################################
## Load data
eff <- read.csv("eff.csv",row.names=1,header=TRUE,stringsAsFactors=FALSE)
sit <- read.csv("sit.csv",row.names=1,header=TRUE,stringsAsFactors=FALSE)
#####################################################################################################
## Prepare Study Area Blocks
setwd(paste(wd,"Dropbox/Bangarang Docs/Humpback-shifts/decade/data/surveyblocks",sep=""))
blocks <- read.csv("blocks.csv",stringsAsFactors=FALSE)
#####################################################################################################
#####################################################################################################
#####################################################################################################
#####################################################################################################

# For each block,
    # In each iteration:
        # Total up sightings seen in all months
        # Redistribute randomly among months
        # Calculate simulated density in each month
        # Store it
    
# Random assignments of HWs within a block to months (only months that received effort)
block.time.randomize <- function(blocknumber){
  sit <- sit.j.global[,blocknumber]
  eff <- eff.j.global[,blocknumber]
  den <- den.j.global[,blocknumber]
  validmonths <- which(eff!=0)
  subsit <- sit[validmonths]  # Subset available blox to only those where effort occurred
  totalsits <- sum(subsit,na.rm=TRUE)
  newmonths <- sample(validmonths,totalsits,replace=TRUE) # Reassign sightings randomly among months that received effort
  # Randomization
  simsit <- rep(0,times=12)  # Pool simulated sightings into their months
  for(i in 1:length(newmonths)){
    m <- newmonths[i]
    simsit[m] <- simsit[m] + 1
  }
  
  # Calculate new density
  simden <- simsit/eff
  return(simden)
}

#####################################################################################################
#####################################################################################################

# Primary Randomization Function
# Works on a julian-pooled block
block.funk <- function(blocknumber,iterations){
  blockvec <- rep(blocknumber,times=iterations)
  results <- sapply(blockvec,block.time.randomize)
  results <- t(results)
  return(results)
}

#####################################################################################################
#####################################################################################################
#####################################################################################################
#####################################################################################################
## RANDOMIZATION TEST:  
#####################################################################################################
## SET UP
B <- 10000
n=12
sit.j.global <<- sit
eff.j.global <<- eff
den.j.global <- sit.j.global/eff.j.global
#####################################################################################################
#####################################################################################################
blockmns <- data.frame()
diffmns <- data.frame()
obsquartile <- matrix(data=NA,nrow=ncol(eff),ncol=12)
for(i in 1:ncol(eff)){
  results <- block.funk(i,B)
  ################################################
  ################################################
  ################################################
  # Store raw results
  filename <- paste0("raw-block-",names(eff)[i],".csv")
  setwd(paste(wd,"Dropbox/Bangarang Docs/Humpback-shifts/randomization/random-results/raw",sep=""))
  write.csv(results,file=filename,row.names=FALSE,quote=FALSE)
  ################################################
  # Find average
  blockmn <- apply(results,2,function(x){mean(x,na.rm=TRUE)})
  blockmns <- rbind(blockmns,blockmn)
  ################################################
  ################################################
  ################################################
  # Observed - Simulated
  observed <- den.j.global[,i]
  diffs <- matrix(nrow=nrow(results),ncol=12)
  for(j in 1:12){
    diffs[,j] <- observed[j] - results[,j]
  }  
  ################################################
  # Store diff results
  filename <- paste0("diff-block-",names(eff)[i],".csv")
  setwd(paste(wd,"Dropbox/Bangarang Docs/Humpback-shifts/randomization/random-results/diff",sep=""))
  write.csv(results,file=filename,row.names=FALSE,quote=FALSE)
  ################################################
  # Find average
  diffmn <- apply(diffs,2,function(x){mean(x,na.rm=TRUE)})
  diffmns <- rbind(diffmns,diffmn) 
  ################################################
  ################################################
  ################################################
  # Find quantile of the observed
  # The proportion of the simulated densities that the observed density is equal to or greater than.
  for(j in 1:12){
    observed <- den.j.global[j,i]
    if(sum(sit.j.global[,i],na.rm=TRUE) >= 1){  # if there werent any sightings in this block ever, don't calc quantile
    if(is.na(results[1,j])==FALSE){
    sorted <- sort(results[,j])
    rankvec <- seq(0,1,length=length(sorted))
    diffij <- abs(observed - sorted)
    matches <- which(diffij==min(diffij))
    index <- matches[length(matches)]
    obsquartile[i,j] <- rankvec[index]
    }
    }
  }  
  ################################################
  # Visualize and report
  par(mfrow=c(4,3))
  par(mar=c(4.5,4.5,4,2))
  for(k in 1:12){
    if(is.na(diffs[1,k])==FALSE){hist(diffs[,k],breaks=20,main=paste0("Block ",i," | Month ",k))}
  }
  print(paste0("Randomization complete for block ",names(eff)[i],"!"))
}
#####################################################################################################
setwd(paste(wd,"Dropbox/Bangarang Docs/Humpback-shifts/randomization/random-results",sep=""))
write.csv(blockmns,file="mean-densities.csv",row.names=FALSE,quote=FALSE)
write.csv(diffmns,file="mean-diffs.csv",row.names=FALSE,quote=FALSE)
write.csv(obsquartile,file="quartiles.csv",row.names=FALSE,quote=FALSE)

#####################################################################################################
#####################################################################################################