#####################################################################################################
#####################################################################################################
### COLORING FUNCTIONS
#####################################################################################################

#####################################################################################################
## Apply color to sightiings according to julian day
juliancol <- function(doy){
  # Color Ramp the julian dates
  # Just do from April 1 (91st Julian day) to December 31st
  library(graphics)
  jet.colors <-colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan","#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))
  coljulian <- rev(jet.colors(365-91))
  coljulian <- c(rep("#00007F",times=91),coljulian)
  doycol <- rep("#00007F",times=length(doy))
  for(i in 1:length(doy)){doycol[i] <- coljulian[doy[i]]}
  return(doycol)
}
#####################################################################################################
####
#####################################################################################################
## Apply Color to effort corrected data
# Data is 1 row long
colfun <- function(data,maxdata){
  data <- as.numeric(data)
  
  blockorder <- c(1,  2,  6,  4,  5,  3,  8,  9, 10,
                  7, 16, 11, 12, 13, 14, 15, 17, 18,
                  19, 22, 23, 20, 24, 21, 25, 28, 31,
                  26, 29, 27, 30, 32, 33, 34, 39, 42, 48, 43, 
                  40, 36, 44, 45, 50, 51, 52, 41, 37, 38, 35, 47, 53, 54, 49, 46)
  
  jet.colors <-colorRampPalette(c("white","cadet blue", "navy blue"))
  cols <- jet.colors(100)
  colbins <- seq(0,maxdata,length=100)
  #
  colreturn <- rep("gray",times=length(data))
  for(i in 1:length(blockorder)){
    blocknum <- blockorder[i]
    datacol <- data[blocknum]
    if(is.na(datacol)==FALSE){
      matchi <- which.min(abs(colbins - datacol))
      colreturn[i] <- cols[matchi]
    }
  }
  return(colreturn)
}
#####################################################################################################
#####
# Match colors used in effort exploration figure
provo.colfun <- function(row,maxdata,mindata=0,colvec){
  blocklist <- list(c(1:18,22,26),
                    c(19,20,21,23,24,25,27,29,30,32,33,34,39),
                    c(25,28,31,36,40,41,48,42,43,44,45),
                    c(37,38,46,47,49,50,51,53,54))
  ## Take a row: a month with 4 values (one for each province):
  row <- as.numeric(row)
  blockvals <- rep(NA,times=54)
  blockvals[blocklist[[1]]] <- row[1]
  blockvals[blocklist[[2]]] <- row[2]
  blockvals[blocklist[[3]]] <- row[3]
  blockvals[blocklist[[4]]] <- row[4]
  ##
  return(rando.colfun(blockvals,maxdata,mindata=0,colvec))
}
#####
#####################################################################################################
#####
#### QUANTILE COLOR FUNCTION
# For blocks
quantile.color <- function(data,colvec){
  # colvec = c( 0-5% , 5-50% , 50-95%, 95-100%)
  data <- as.numeric(data)
  
  blockorder <- c(1,  2,  6,  4,  5,  3,  8,  9, 10,
                  7, 16, 11, 12, 13, 14, 15, 17, 18,
                  19, 22, 23, 20, 24, 21, 25, 28, 31,
                  26, 29, 27, 30, 32, 33, 34, 39, 42, 48, 43, 
                  40, 36, 44, 45, 50, 51, 52, 41, 37, 38, 35, 47, 53, 54, 49, 46)
  
  colreturn <- rep("gray",times=length(data))
  for(i in 1:length(blockorder)){
    blocknum <- blockorder[i]
    datacol <- data[blocknum]
    if(is.na(datacol)==FALSE){
      if(datacol >= 0 & datacol <= .05){colreturn[i] <- colvec[1]}
      if(datacol > .05 & datacol <= .5){colreturn[i] <- colvec[2]}
      if(datacol > .5 & datacol <= .95){colreturn[i] <- colvec[3]}
      if(datacol > .95 & datacol <= 1){colreturn[i] <- colvec[4]}
    }
  }
  return(colreturn)
}
#####
#####################################################################################################
#####
# For provinces
quantile.color.prov <- function(row,colvec){
  ##
  blocklist <- list(c(1:18,22,26),
                    c(19,20,21,23,24,25,27,29,30,32,33,34,39),
                    c(25,28,31,36,40,41,48,42,43,44,45),
                    c(37,38,46,47,49,50,51,53,54))
  ## Take a row: a month with 4 values (one for each province):
  row <- as.numeric(row)
  blockvals <- rep(NA,times=54)
  blockvals[blocklist[[1]]] <- row[1]
  blockvals[blocklist[[2]]] <- row[2]
  blockvals[blocklist[[3]]] <- row[3]
  blockvals[blocklist[[4]]] <- row[4]
  ##
  return(quantile.color(blockvals,colvec))    
}









