###### PROVINCE MAPPING FUNCTIONS


###########
#####################################################################################################
#####################################################################################################
#####################################################################################################
#####################################################################################################
# Match colors used in effort exploration figure
channel.colfun <- function(row,maxdata,mindata=0,colvec){
  row <- as.numeric(row)
  jet.colors <-colorRampPalette(colvec)
  cols <- jet.colors(100)
  colbins <- seq(mindata,maxdata,length=100)
  #
  colreturn <- rep("gray",times=length(data))
  for(i in 1:length(row)){
    datum <- row[i]
    if(is.na(datum)==FALSE){
      matchi <- which.min(abs(colbins - datum))
      colreturn[i] <- cols[matchi]
    }
  }
  return(colreturn)
}
############
# Quantile coloration for channels
quantile.color.ch <- function(data,maxdata=1,mindata=0,colvec){
  # colvec = c( 0-5% , 5-50% , 50-95%, 95-100%)
  data <- as.numeric(data)
  colreturn <- rep("gray",times=length(data))
  for(i in 1:length(data)){
    datacol <- data[i]
    if(is.na(datacol)==FALSE){
      if(datacol >= mindata & datacol <= .05){colreturn[i] <- colvec[1]}
      if(datacol > .05 & datacol <= .5){colreturn[i] <- colvec[2]}
      if(datacol > .5 & datacol <= .95){colreturn[i] <- colvec[3]}
      if(datacol > .95 & datacol <= maxdata){colreturn[i] <- colvec[4]}
    }
  }
  return(colreturn)
}
#####################################################################################################
#####################################################################################################
#####################################################################################################
#####################################################################################################
# Plot 6 months of province-blocked abundance estimates - for year by year comparison
channel.wave.plot <- function(abun,maxdata,mindata,colvec=c("white","cadet blue","navy blue"),colfunk="grade",tit="",tittog=TRUE){
  curdir <- getwd()
  setwd(paste(wd,"Dropbox/Bangarang Docs/Humpback-shifts/raw-datasets/surveyblocks",sep=""))
  blocks <- read.csv("blocks.csv",stringsAsFactors=FALSE)
  channels <- as.character(unique(blocks$channel))
  chans <- read.csv("channelpolygons.csv")
  chanorder <- as.character(unique(chans$province))
  setwd(curdir)
  ########
  ########
  # Re-order abundance dataframe to align with channels polygon
  abund <- data.frame(abun)  
  abund$dou <- abund$dev <- abund$ sur <- abund$gre <- abund$fra <- NULL
  abundorder <- vector()
  for(i in chanorder){ abundorder <- c(abundorder,which(names(abund)==i)) }
  abun <- abund[,abundorder]
  ########
  ########
  if(colfunk=="grade"){coloring <- channel.colfun}
  if(colfunk=="quantile"){coloring <- quantile.color.ch}
  #########
  if(tittog){par(mar=c(.2,2,2.5,.2))}else{par(mar=c(.2,2,1,.2))}
  #par(mfrow=c(2,3))
  plotPolys(closePolys(chans),col=coloring(abun[6,],maxdata,mindata,colvec),bg=adjustcolor("lightyellow3",alpha.f=.2),axes=FALSE,ann=FALSE,border=adjustcolor("black",alpha.f=.5))
  title(ylab=tit,cex.lab=1.3,line=0.5)
  if(tittog){title(main="June")}
  if(tittog){par(mar=c(.2,2,2.5,.2))}else{par(mar=c(.2,2,1,.2))}
  plotPolys(closePolys(chans),col=coloring(abun[7,],maxdata,mindata,colvec),bg=adjustcolor("lightyellow3",alpha.f=.2),axes=FALSE,ann=FALSE,border=adjustcolor("black",alpha.f=.5))
  if(tittog){title(main="July")}
  plotPolys(closePolys(chans),col=coloring(abun[8,],maxdata,mindata,colvec),bg=adjustcolor("lightyellow3",alpha.f=.2),axes=FALSE,ann=FALSE,border=adjustcolor("black",alpha.f=.5))
  if(tittog){title(main="Aug.")}
  plotPolys(closePolys(chans),col=coloring(abun[9,],maxdata,mindata,colvec),bg=adjustcolor("lightyellow3",alpha.f=.2),axes=FALSE,ann=FALSE,border=adjustcolor("black",alpha.f=.5))
  if(tittog){title(main="Sept.")}
  plotPolys(closePolys(chans),col=coloring(abun[10,],maxdata,mindata,colvec),bg=adjustcolor("lightyellow3",alpha.f=.2),axes=FALSE,ann=FALSE,border=adjustcolor("black",alpha.f=.5))
  if(tittog){title(main="Oct.")}
  plotPolys(closePolys(chans),col=coloring(abun[11,],maxdata,mindata,colvec),bg=adjustcolor("lightyellow3",alpha.f=.2),axes=FALSE,ann=FALSE,border=adjustcolor("black",alpha.f=.5))
  if(tittog){title(main="Nov.")}
  #par(mfrow=c(1,1))
}
# Test it:
#maxdata = 1
#mindata = 0
#colvec <- c("firebrick",adjustcolor("firebrick",alpha.f=.5),"light blue","steelblue4")
#par(mfrow=c(2,3))
#channel.wave.plot(abun,maxdata,mindata,colvec,colfunk="quantile",tittog=TRUE)
############
############
#####################################################################################################
#####################################################################################################
#############